# Resolvers

[Licensecheck Index](../../README.md#licensecheck-index) / [Licensecheck](../index.md#licensecheck) / Resolvers

> Auto-generated documentation for [licensecheck.resolvers](../../../../licensecheck/resolvers/__init__.py) module.

- [Resolvers](#resolvers)
  - [Modules](#modules)

## Modules

- [Native](./native.md)
- [Uv](./uv.md)